==> jc-1.4.0.tar.gz: soot/toolkits/scalar/SimpleLiveLocalsAnalysis.h <==
// class soot.toolkits.scalar.SimpleLiveLocalsAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 722d252e8e2e5e52 soot_toolkits_scalar_BackwardFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 58f50a0ae2b1aeaa soot_toolkits_scalar_SimpleLiveLocalsAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_BackwardFlowAnalysis

#include "soot/toolkits/scalar/BackwardFlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_SimpleLiveLocalsAnalysis_H_
#define _JC_soot_toolkits_scalar_SimpleLiveLocalsAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_refs	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$refs	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$nonrefs	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vmethods	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtable	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtype	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *);

// Virtual methods
extern void _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *);
extern void _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *);
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods	soot_toolkits_scalar_BackwardFlowAnalysis;
	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vmethods	soot_toolkits_scalar_SimpleLiveLocalsAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_refs {
	struct _jc_object	*emptySet;
	struct _jc_object	*unitToGenerateSet;
	struct _jc_object	*unitToPreserveSet;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$refs {
    _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_refs	soot_toolkits_scalar_SimpleLiveLocalsAnalysis;
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs	soot_toolkits_scalar_BackwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BackwardFlowAnalysis;
    _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_nonrefs	soot_toolkits_scalar_SimpleLiveLocalsAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object {
	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtype _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_SimpleLiveLocalsAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_SimpleLiveLocalsAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/SimpleLiveLocalsAnalysis.h <==
// class soot.toolkits.scalar.SimpleLiveLocalsAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 722d252e8e2e5e52 soot_toolkits_scalar_BackwardFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 58f50a0ae2b1aeaa soot_toolkits_scalar_SimpleLiveLocalsAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_BackwardFlowAnalysis

#include "soot/toolkits/scalar/BackwardFlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_SimpleLiveLocalsAnalysis_H_
#define _JC_soot_toolkits_scalar_SimpleLiveLocalsAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_refs	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$refs	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$nonrefs	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vmethods	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtable	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtype	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *) _JC_JCNI_ATTR;
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods	soot_toolkits_scalar_BackwardFlowAnalysis;
	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vmethods	soot_toolkits_scalar_SimpleLiveLocalsAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_refs {
	struct _jc_object	*emptySet;
	struct _jc_object	*unitToGenerateSet;
	struct _jc_object	*unitToPreserveSet;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$refs {
    _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_refs	soot_toolkits_scalar_SimpleLiveLocalsAnalysis;
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs	soot_toolkits_scalar_BackwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BackwardFlowAnalysis;
    _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$sub_nonrefs	soot_toolkits_scalar_SimpleLiveLocalsAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$object {
	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$vtype _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_SimpleLiveLocalsAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_SimpleLiveLocalsAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_SimpleLiveLocalsAnalysis_H_ */
